===========================
 Heat Template Definitions
===========================

Heat Templates are what Magnum uses to generate a Bay. These various template
definitions provide a mapping of Magnum object attributes to Heat templates
parameters, along with Magnum consumable template outputs. The result of a
Heat template should be a full Container Orchestration Environment.

.. list-plugins:: magnum.template_definitions
   :detailed:
